searchNodes=[{"doc":"The main module of Jason.Structs . It provides functions for encoding and decoding JSON to and from structs. The encode functions are basically delegating to Jason.encode , as the Jason.Encoder is automatically implemented for all Jason.Structs.Struct modules. The decode functions are delegating to Jason.Structs.Decoder . We can have: defmodule Country do use Jason.Structs.Struct jason_struct do field ( :code , String . t ( ) , enforce : true ) field ( :name , String . t ( ) , enforce : true ) end end this is a Jason.Structs.Struct now, so if we have the following JSON: json = ~s( { &quot;code&quot;: &quot;bg&quot;, &quot;name&quot;: &quot;Bulgaria&quot; } ) By using: Jason.Structs . decode! ( json , Country ) we get: % Country { code : &quot;bg&quot; , name : &quot;Bulgaria&quot; } And we can convert country = % Country { code : &quot;bg&quot; , name : &quot;Bulgaria&quot; } to JSON like this: country |&gt; Jason.Structs . encode! ( pretty : true ) |&gt; IO . puts ( ) { &quot;code&quot; : &quot;bg&quot; , &quot;name&quot; : &quot;Bulgaria&quot; }","ref":"Jason.Structs.html","title":"Jason.Structs","type":"module"},{"doc":"Parses a JSON value from input iodata and if a struct_module is provided, which is a Jason.Structs.Struct implementation, the parsed result will be an instance of that struct. By skipping the struct_module it works like the normal Jason.decode function. It can parse all valid JSON values that way (numbers, lists, booleans, objects, strings, null). Examples defmodule Country do use Jason.Structs.Struct jason_struct do field ( :code , String . t ( ) , enforce : true ) field ( :name , String . t ( ) , enforce : true ) end end iex&gt; json = ~s({&quot;name&quot;: &quot;Bulgaria&quot;, &quot;code&quot;: &quot;bg&quot;}) iex&gt; Jason.Structs . decode ( json , Country ) { :ok , % Country { code : &quot;bg&quot; , name : &quot;Bulgaria&quot; } } iex&gt; json = ~s({&quot;name&quot;: &quot;Bulgaria&quot;, &quot;code&quot;: &quot;bg&quot;}) iex&gt; Jason.Structs . decode ( json ) { :ok , %{ code : &quot;bg&quot; , name : &quot;Bulgaria&quot; } } iex&gt; json = &quot;55&quot; iex&gt; Jason.Structs . decode ( json ) { :ok , 55 } iex&gt; Jason.Structs . decode ( &quot;invalid&quot; ) { :error , % Jason.DecodeError { data : &quot;invalid&quot; , position : 0 , token : nil } }","ref":"Jason.Structs.html#decode/2","title":"Jason.Structs.decode/2","type":"function"},{"doc":"Parses a JSON value from input iodata and if a struct_module is provided, which is a Jason.Structs.Struct implementation, the parsed result will be an instance of that struct. Similar to decode/2 except it will unwrap the error tuple and raise in case of errors. By skipping the struct_module it works like the normal Jason.decode! function. It can parse all valid JSON values that way (numbers, lists, booleans, objects, strings, null). Examples defmodule Country do use Jason.Structs.Struct jason_struct do field ( :code , String . t ( ) , enforce : true ) field ( :name , String . t ( ) , enforce : true ) end end iex&gt; json = ~s({&quot;name&quot;: &quot;Bulgaria&quot;, &quot;code&quot;: &quot;bg&quot;}) iex&gt; Jason.Structs . decode! ( json , Country ) % Country { code : &quot;bg&quot; , name : &quot;Bulgaria&quot; } iex&gt; json = ~s({&quot;name&quot;: &quot;Bulgaria&quot;, &quot;code&quot;: &quot;bg&quot;}) iex&gt; Jason.Structs . decode! ( json ) %{ code : &quot;bg&quot; , name : &quot;Bulgaria&quot; } iex&gt; Jason.Structs . decode! ( &quot;true&quot; ) true iex&gt; Jason.Structs . decode! ( &quot;invalid&quot; ) ** (Jason.DecodeError) unexpected byte at position 0: 0x69 (&#39;i&#39;)","ref":"Jason.Structs.html#decode!/2","title":"Jason.Structs.decode!/2","type":"function"},{"doc":"Generates JSON corresponding to the input . See Jason.encode/2 for more information, as it delegates to it. The Jason.Structs.Struct structs automatically implement the Jason.Encoder protocol with a custom implementation, so all of them can be encoded to JSON. Examples defmodule Country do use Jason.Structs.Struct jason_struct do field ( :code , String . t ( ) , enforce : true ) field ( :name , String . t ( ) , enforce : true ) end end iex&gt; country = % Country { code : &quot;bg&quot; , name : &quot;Bulgaria&quot; } iex&gt; Jason.Structs . encode ( country ) { :ok , ~s({&quot;code&quot;:&quot;bg&quot;,&quot;name&quot;:&quot;Bulgaria&quot;}) }","ref":"Jason.Structs.html#encode/2","title":"Jason.Structs.encode/2","type":"function"},{"doc":"Generates JSON corresponding to input. Similar to encode/1 except it will unwrap the error tuple and raise in case of errors. See Jason.encode!/2 for more information, as it delegates to it. The Jason.Structs.Struct structs automatically implement the Jason.Encoder protocol with a custom implementation, so all of them can be encoded to JSON. Examples defmodule Country do use Jason.Structs.Struct jason_struct do field ( :code , String . t ( ) , enforce : true ) field ( :name , String . t ( ) , enforce : true ) end end iex&gt; country = % Country { code : &quot;bg&quot; , name : &quot;Bulgaria&quot; } iex&gt; Jason.Structs . encode! ( country ) ~s({&quot;code&quot;:&quot;bg&quot;,&quot;name&quot;:&quot;Bulgaria&quot;})","ref":"Jason.Structs.html#encode!/2","title":"Jason.Structs.encode!/2","type":"function"},{"doc":"A JSON Decoder that can decode a JSON to a Jason.Structs struct, if its module is provided. The decoding process is recursive and if the strcut has fields that are Jason.Structs structs, they are also decoded. If the struct has fields, that are normal structs they'll be decoded as maps.","ref":"Jason.Structs.Decoder.html","title":"Jason.Structs.Decoder","type":"module"},{"doc":"Decodes the passed iodata JSON to a struct of the given struc_module type. If the struc_module is passed as nil , the result is just a map.","ref":"Jason.Structs.Decoder.html#decode/2","title":"Jason.Structs.Decoder.decode/2","type":"function"},{"doc":"Implementation that is applied to all the Jason.Structs structs. Basically it encodes the structs, defined with the DSL provided by Jason.Structs to JSON. By default all keys are transofrmed from snake-styled expressions to cammel-styled expressions.","ref":"Jason.Structs.Encoder.html","title":"Jason.Structs.Encoder","type":"module"},{"doc":"Implements the Jason.Encoder.encode function for Jason.Structs structs.","ref":"Jason.Structs.Encoder.html#encode/2","title":"Jason.Structs.Encoder.encode/2","type":"function"},{"doc":"","ref":"Jason.Structs.Encoder.html#t:opts/0","title":"Jason.Structs.Encoder.opts/0","type":"opaque"},{"doc":"This module defines the jason_struct macro, which can be used to define a struct convertable to JSON and decodable from JSON. An example of such a module could be: defmodule Country do use Jason.Structs.Struct jason_struct do field ( :code , String . t ( ) , enforce : true ) field ( :name , String . t ( ) , enforce : true ) end end Here we use Jason.Structs.Struct and now we can define the struct, using the jason_struct macro. This will change the module to look like this: defmodule Country do @type t ( ) :: % Country { code : String . t ( ) , name : String . t ( ) } @enforce_keys [ :code , :name ] defstruct code : nil , name : nil end Note that the macro generates some functions that are used by the encoding and decoding logic and they are excluded from this example. It is possible to define structs, referencing other Jason.Structs structs: defmodule Address do use Jason.Structs.Struct jason_struct do field ( :city , String . t ( ) , enforce : true ) field ( :street_address_line_one , String . t ( ) , enforce : true ) field ( :street_address_line_two , String . t ( ) , enforce : false , excludable : true ) field ( :country , Country . t ( ) , enforce : true ) end end Here we are defining a country field of type Country.t() this will work fine. It is possible to have recursive references and references in lists: defmodule User do use Jason.Structs.Struct jason_struct do field ( :name , String . t ( ) , enforce : true ) field ( :address , Address . t ( ) , enforce : true ) field ( :children , [ User . t ( ) ] , excludable : true ) end end The User can have a list of children of type User . With these definitions if we try to decode ( Jason.Structs.decode!(json_string, User) ) the following JSON: { &quot;address&quot; : { &quot;city&quot; : &quot;Yambol&quot; , &quot;country&quot; : { &quot;code&quot; : &quot;bg&quot; , &quot;name&quot; : &quot;Bulgaria&quot; } , &quot;streetAddressLineOne&quot; : &quot;jk. Graph Ignatiev&quot; } , &quot;children&quot; : [ { &quot;address&quot; : { &quot;city&quot; : &quot;Yambol&quot; , &quot;country&quot; : { &quot;code&quot; : &quot;bg&quot; , &quot;name&quot; : &quot;Bulgaria&quot; } , &quot;streetAddressLineOne&quot; : &quot;jk. Graph Ignatiev&quot; } , &quot;name&quot; : &quot;Ivan Petrov&quot; } ] , &quot;name&quot; : &quot;Petur Petrov&quot; } We'll get the following struct instance: % User { address : % Address { city : &quot;Yambol&quot; , country : % Country { code : &quot;bg&quot; , name : &quot;Bulgaria&quot; } , street_address_line_one : &quot;jk. Graph Ignatiev&quot; , street_address_line_two : nil } , children : [ % User { address : % Address { city : &quot;Yambol&quot; , country : % Country { code : &quot;bg&quot; , name : &quot;Bulgaria&quot; } , street_address_line_one : &quot;jk. Graph Ignatiev&quot; , street_address_line_two : nil } , children : nil , name : &quot;Ivan Petrov&quot; } ] , name : &quot;Petur Petrov&quot; } By using this Jason.Structs.Struct , the module using it will also get special Jason.Encoder implementation, so it will be possible to encode it with Jason.encode(struct_instance) .","ref":"Jason.Structs.Struct.html","title":"Jason.Structs.Struct","type":"module"},{"doc":"Defines a Jason.Structs struct. As this library uses Typed Struct for the implementation, every field defined in the body of the macro supports the options supported by TypedStruct.typedstruct/2 . Options for the fields: enforce - if set to true, add this field to the @enforce_keys list. excludable - if the value of the field is nil , when the struct is encoded into JSON, the field is excluded. default - a default value for the field, if it is not set to something else. Example jason_struct do field ( :name , String . t ( ) , enforce : true , default : &quot;Petar&quot; ) field ( :address , Address . t ( ) , enforce : true ) field ( :children , [ User . t ( ) ] , excludable : true ) end","ref":"Jason.Structs.Struct.html#jason_struct/1","title":"Jason.Structs.Struct.jason_struct/1","type":"macro"},{"doc":"A Typed Struct plugin, used to customize a definition of a TypedStruct . This plugin converts a TypedStruct into a Jason.Structs.Struct by adding specific properties and functions needed for JSON encoding and decoding. This plugin is applied automatically to any module with the expression use Jason.Structs.Struct in it.","ref":"Jason.Structs.TypedStructPlugin.html","title":"Jason.Structs.TypedStructPlugin","type":"module"},{"doc":"JasonStructs A Jason plugin library that adds the ability to encode and decode structs to and from JSON. Uses the brilliant library Typed Struct to define a DSL for defining structs convertable to JSON in Elixir. It adds to Jason the ability to convert these types of structs.","ref":"readme.html","title":"JasonStructs","type":"extras"},{"doc":"It is available in Hex , so the package can be installed by adding jason_structs to your list of dependencies in mix.exs : def deps do [ { :jason_structs , &quot;~&gt; 0.1.0&quot; } ] end","ref":"readme.html#installation","title":"JasonStructs - Installation","type":"extras"},{"doc":"We can define structs like this (see the tests): defmodule Country do use Jason.Structs.Struct jason_struct do field ( :code , String . t ( ) , enforce : true ) field ( :name , String . t ( ) , enforce : true ) end end defmodule Address do use Jason.Structs.Struct jason_struct do field ( :city , String . t ( ) , enforce : true ) field ( :street_address_line_one , String . t ( ) , enforce : true ) field ( :street_address_line_two , String . t ( ) , enforce : false , excludable : true ) field ( :post_code , String . t ( ) , enforce : false ) field ( :country , Country . t ( ) , enforce : true ) end end defmodule Interest do use Jason.Structs.Struct jason_struct do field ( :name , String . t ( ) , enforce : true ) field ( :description , String . t ( ) , enforce : true ) end end defmodule User do use Jason.Structs.Struct jason_struct do field ( :name , String . t ( ) , enforce : true ) field ( :age , integer ( ) , enforce : true ) field ( :sex , :male | :female , enforce : true , default : :female ) field ( :address , Address . t ( ) , enforce : true ) field ( :interests , list ( ) , excludable : true , default : [ ] ) field ( :children , [ User . t ( ) ] , excludable : true ) field ( :likes_json_structs , boolean ( ) , default : true ) end end And if we have instances of these structs like these: ivancho = % User { name : &quot;Ivan Petrov&quot; , age : 10 , sex : :male , address : % Address { city : &quot;Yambol&quot; , street_address_line_one : &quot;jk. Graph Ignatiev&quot; , street_address_line_two : &quot;bl. 72&quot; , post_code : &quot;8600&quot; , country : % Country { code : :bg , name : &quot;Bulgaria&quot; } } , interests : [ % Interest { name : &quot;Call Of Duty&quot; , description : &quot;A FPS!&quot; } , % Interest { name : &quot;Minecraft&quot; , description : &quot;Blocks and stuff!&quot; } ] , likes_json_structs : false } pesho = % User { name : &quot;Petur Petrov&quot; , age : 35 , sex : :male , address : % Address { city : &quot;Yambol&quot; , street_address_line_one : &quot;jk. Graph Ignatiev&quot; , street_address_line_two : &quot;bl. 72&quot; , post_code : &quot;8600&quot; , country : % Country { code : :bg , name : &quot;Bulgaria&quot; } } , interests : [ % Interest { name : &quot;football&quot; , description : &quot;Some people running after a ball and kicking it.&quot; } , % Interest { name : &quot;rakia&quot; , description : &quot;Alcoholic bevarage, very loved on the Balkans.&quot; } , % Interest { name : &quot;salata&quot; , description : &quot;Obicham shopskata salata, mastika ledena da pia.&quot; } ] , children : [ ivancho ] , likes_json_structs : false } We can just do {ok, json} = Jason.encode(pesho) to get: { &quot;address&quot;: { &quot;city&quot;: &quot;Yambol&quot;, &quot;country&quot;: { &quot;code&quot;: &quot;bg&quot;, &quot;name&quot;: &quot;Bulgaria&quot; }, &quot;postCode&quot;: &quot;8600&quot;, &quot;streetAddressLineOne&quot;: &quot;jk. Graph Ignatiev&quot;, &quot;streetAddressLineTwo&quot;: &quot;bl. 72&quot; }, &quot;age&quot;: 35, &quot;children&quot;: [ { &quot;address&quot;: { &quot;city&quot;: &quot;Yambol&quot;, &quot;country&quot;: { &quot;code&quot;: &quot;bg&quot;, &quot;name&quot;: &quot;Bulgaria&quot; }, &quot;postCode&quot;: &quot;8600&quot;, &quot;streetAddressLineOne&quot;: &quot;jk. Graph Ignatiev&quot;, &quot;streetAddressLineTwo&quot;: &quot;bl. 72&quot; }, &quot;age&quot;: 10, &quot;interests&quot;: [ { &quot;description&quot;: &quot;A FPS!&quot;, &quot;name&quot;: &quot;Call Of Duty&quot; }, { &quot;description&quot;: &quot;Blocks and stuff!&quot;, &quot;name&quot;: &quot;Minecraft&quot; } ], &quot;likesJsonStructs&quot;: false, &quot;name&quot;: &quot;Ivan Petrov&quot;, &quot;sex&quot;: &quot;male&quot; } ], &quot;interests&quot;: [ { &quot;description&quot;: &quot;Some people running after a ball and kicking it.&quot;, &quot;name&quot;: &quot;football&quot; }, { &quot;description&quot;: &quot;Alcoholic bevarage, very loved on the Balkans.&quot;, &quot;name&quot;: &quot;rakia&quot; }, { &quot;description&quot;: &quot;Obicham shopskata salata, mastika ledena da pia.&quot;, &quot;name&quot;: &quot;salata&quot; } ], &quot;likesJsonStructs&quot;: false, &quot;name&quot;: &quot;Petur Petrov&quot;, &quot;sex&quot;: &quot;male&quot; } And don't forget : YAMBOL IS THE CITY!","ref":"readme.html#examples","title":"JasonStructs - Examples","type":"extras"}]